@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 1996-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+    Copyright (C) 1996-2002  Ulric Eriksson <ulric@siag.nu>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <ctype.h>
 #include <signal.h>
 #include <unistd.h>
@@ -27,12 +28,12 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include "../config.h"
-#include "cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "common.h"
+#include <Mowitz/MwUtils.h>
 
 /*#define DEBUG
 */
-#include "traceme.h"
 
 /* ---
 common.c
@@ -44,49 +45,45 @@ Device independent functions for all three programs.
 Figure out the names of directories
 */
 
-char *libexecdir; /* where plugins are; default /usr/local/libexec/siag */
+char *libdir; /* where plugins are; default /usr/local/lib/siag */
 char *datadir;	  /* where Scheme files are; default /usr/local/share/siag */
 char *docdir;	  /* where online docs are; default /usr/local/doc/siag */
-char *siaghelp;	  /* what displays html; default $docdir/common/siaghelp */
 char *siag_basedir;	/* $HOME/.siag */
+char *siag_tmpdir;	/* $HOME/.siag/tmp */
 char *version;	  /* version string */
 
 void common_init(char *fmt)
 {
 	char *home = getenv("SIAGHOME");
 	char *docs = getenv("SIAGDOCS");
-	char *help = getenv("SIAGHELP");
 	char *lang;
 	char p[1024];
 
 	if (home) {
-		libexecdir = datadir = cstrdup(home);
+		libdir = datadir = MwStrdup(home);
 	} else {
-		libexecdir = LIBEXECDIR;
+		libdir = LIBDIR;
 		datadir = DATADIR;
 	}
 	if (docs) {
-		docdir = cstrdup(docs);
+		docdir = MwStrdup(docs);
 	} else {
 		docdir = DOCDIR;
 	}
-	if (help) {
-		siaghelp = cstrdup(help);
-	} else {
-		sprintf(p, "%s/common/siaghelp", docdir);
-		siaghelp = cstrdup(p);
-	}
 	if (fmt) {
 		sprintf(p, fmt, VERSION_NO);
 	} else {
 		sprintf(p, "Siag Office %s", VERSION_NO);
 	}
-	version = cstrdup(p);
+	version = MwStrdup(p);
 	home = getenv("HOME");
 	if (home == NULL) home = "";
 	sprintf(p, "%s/.siag", home);
-	siag_basedir = cstrdup(p);
+	siag_basedir = MwStrdup(p);
 	mkdir(siag_basedir, 0700);
+	strcat(p, "/tmp");
+	siag_tmpdir = MwStrdup(p);
+	mkdir(siag_tmpdir, 0700);
 
 	/* i18n */
 	lang = getenv("LC_ALL");
@@ -94,71 +91,21 @@ void common_init(char *fmt)
 	if (lang == NULL) lang = getenv("LANG");
 	if (lang) {
 		sprintf(p, "%s/common/dictionary.%s", datadir, lang);
-		load_dictionary(p);
+		MwLoadDictionary(p);
 	}
 }
 
-/* ---
-Strip trailing newline, if there is one
-*/
-
-void chomp(char *p)
-{
-	if ((p = strchr(p, '\n'))) *p = '\0';
-}
-
 /* ---
 Check if a string should be interpreted as a positive answer.
 */
 
 int itsayes(char *p)
 {
-	return !cstrcasecmp(p, "yes")
-		|| !cstrcasecmp(p, "1")
-		|| !cstrcasecmp(p, "on")
-		|| !cstrcasecmp(p, translate("yes"))
-		|| !cstrcasecmp(p, translate("on"));
-}
-
-/* ---
-Case insensitive compare
-*/
-
-int cstrcasecmp(const char *p, const char *q)
-{
-	int c;
-
-	while (!(c = toupper(*p)-toupper(*q)) && *p) {
-		p++;
-		q++;
-	}
-	return c;
-}
-
-/* ---
-Case insensitive compare, length limited
-*/
-
-int cstrncasecmp(const char *p, const char *q, size_t n)
-{
-	size_t i = 0;
-	int c = 0;
-
-	while ((i < n) && !(c = toupper(*p)-toupper(*q)) && *p) {
-		p++;
-		q++;
-		i++;
-	}
-	return c;
-}
-
-/* ---
-Delete all temp directories whose processes are no longer around.
-NB: Doesn't do anything at all.
-*/
-
-void stale_dirs(char *dn)
-{
+	return !MwStrcasecmp(p, "yes")
+		|| !MwStrcasecmp(p, "1")
+		|| !MwStrcasecmp(p, "on")
+		|| !MwStrcasecmp(p, _("yes"))
+		|| !MwStrcasecmp(p, _("on"));
 }
 
 /* a little bookkeeping to keep track of temp files and make sure they
@@ -182,10 +129,10 @@ void deletia_add(long p, char *fn)
 		if (deletia[i].fn == NULL) break;
 	if (i == ndeletia) {
 		ndeletia++;
-		deletia = crealloc(deletia, ndeletia*sizeof *deletia);
+		deletia = MwRealloc(deletia, ndeletia*sizeof *deletia);
 	}
 	deletia[i].p = p;
-	deletia[i].fn = cstrdup(fn);
+	deletia[i].fn = MwStrdup(fn);
 }
 
 /* ---
@@ -214,7 +161,7 @@ void deletia_reap(void)
 	for (i = 0; i < ndeletia; i++) {
 		if (deletia[i].p == 0 && deletia[i].fn) {
 			remove(deletia[i].fn);
-			cfree(deletia[i].fn);
+			MwFree(deletia[i].fn);
 			deletia[i].fn = NULL;
 		}
 	}
@@ -275,98 +222,25 @@ int tryuntar(char *fn, char *index)
 	return result;
 }
 
-/* ---
-A function that doesn't do anything. Can be used to set break points
-during debugging.
-*/
-
-void dummy_fun(void)
+int only_space(char *p)
 {
-	;
+	while (*p && isspace(*p)) p++;
+	return (*p == '\0');
 }
 
-static struct {
-	char *key, *xl;
-} *dict = NULL;
-
-static long nw = 0;
-
-/* ---
-Load the message string dictionary from $(SIAGHOME)/common/dictionary.$(LANG)
-*/
-
-void load_dictionary(char *fn)
+char *plugin_basedir(char *dir, char *bufname)
 {
-        FILE *fp;
-        char b[1024], *p, *q;
+	int i;
+	pid_t pid = getpid();
 
-	/* convert everything after language code to upper case */
-	p = strchr(fn, '_');
-	if (p) {
-		q = p;
-		while (*q) {
-			*q = toupper(*q);
-			q++;
-		}
-	}
-
-	if (p) {
-		q = strchr(p, '.');
-	} else {
-		q = NULL;
-	}
-
-	fp = fopen(fn, "r");
-	
-	if (!fp && q) {
-		/* try abridged file name */
-		*q = '\0';
-		fp = fopen(fn, "r");
-	}
-	if (!fp && p) {
-		/* try abridged file name */
-		*p = '\0';
-		fp = fopen(fn, "r");
-	}
-        if (!fp) {
-#ifdef DEBUG
-                fprintf(stderr, "Can't open dictionary\n");
-#endif
-                return;
-        }
-        while (fgets(b, sizeof b, fp)) {
-                chomp(b);
-                p = strchr(b, '\t');
-                if (!p) continue;
-                *p++ = 0;
-                p += strspn(p, "\t");
-                dict = crealloc(dict, (nw+1)*(sizeof dict[0]));
-                dict[nw].key = cstrdup(b);
-                dict[nw++].xl = cstrdup(p);
-        }
-}
-
-/* ---
-Translate a message string. If no match is found, the key is returned.
-By using English keys, an application can keep working even when the
-dictionary is incomplete.
-990113: tree search through sorted list
-*/
-
-char *translate(char *key)
-{
-	long lower = 0, upper = nw-1;
-        long i;
-	int d;
-
-	while (lower <= upper) {
-		i = (lower+upper)/2;
-		d = strcmp(key, dict[i].key);
-		if (d == 0) return dict[i].xl;
-		else if (d > 0) lower = i+1;
-		else upper = i-1;
-	}
-        return key;
+	sprintf(dir, "%s/%ld/%s", siag_basedir, (long)pid, bufname);
+	for (i = strlen(dir)-strlen(bufname); dir[i]; i++)
+		if (!isalnum(dir[i])) dir[i] = '_';
+	return dir;
 }
 
 
+/* global variables */
+
+int pr_scr_flag;                /* if the display needs updating */
+int input_warp_pointer;         /* move cursor to input field */
