@@ -68,10 +68,10 @@ struct documentmedia papersizes[] = {
 };
 
 
-static char *readline();
-static char *gettextline();
-static char *gettext();
-static int  blank();
+static char *readline(char *, int, FILE *, long *, unsigned int *);
+static char *gettextline(char *);
+static char *gettext(char *, char **);
+static int  blank(char *);
 
 /*
  *	psscan -- scan the PostScript file for document structuring comments.
@@ -843,9 +843,9 @@ continuepage:
 			    &(doc->pages[doc->numpages].boundingbox[LLX]),
 			    &(doc->pages[doc->numpages].boundingbox[LLY]),
 			    &(doc->pages[doc->numpages].boundingbox[URX]),
-			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4)
+			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4) {
 			if (page_bb_set == NONE) page_bb_set = 1;
-		    else {
+		    } else {
 			float fllx, flly, furx, fury;
 			if (sscanf(line+length("%%PageBoundingBox:"),
 				   "%f %f %f %f",
