@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -27,12 +27,10 @@
 #include <stdarg.h>
 #include <ctype.h>
 
-#include "types.h"
-
 #include "egon.h"
 #include "../siod/siod.h"
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 
 int errorflag;
 
@@ -42,8 +40,8 @@ int interpreter_count;
 
 static struct {
 	char *name;
-	double (*evalfn)();
-	void (*execfn)();
+	double (*evalfn)(char *);
+	void (*execfn)(char *);
 } interpreters[MAX_INTERPRETERS];
 
 char *intnames[MAX_INTERPRETERS];
@@ -63,18 +61,19 @@ int name2interpreter(char *name)
 {
 	int i;
 	for (i = 0; i < interpreter_count; i++)
-		if (!cstrcasecmp(name, interpreters[i].name)) return i;
+		if (!MwStrcasecmp(name, interpreters[i].name)) return i;
 	return -1;
 }
 
 /* ---
 */
-int register_interpreter(char *name, double (*evalfn)(), void (*execfn)())
+int register_interpreter(char *name,
+		double (*evalfn)(char *), void (*execfn)(char *))
 {
 	if (interpreter_count >= MAX_INTERPRETERS) return -1;
 	interpreters[interpreter_count].evalfn = evalfn;
 	interpreters[interpreter_count].execfn = execfn;
-	interpreters[interpreter_count].name = cstrdup(name);
+	interpreters[interpreter_count].name = MwStrdup(name);
 	intnames[interpreter_count] = interpreters[interpreter_count].name;
 	intnames[interpreter_count+1] = NULL;
 	return interpreter_count++;
@@ -84,7 +83,7 @@ int register_interpreter(char *name, double (*evalfn)(), void (*execfn)())
 */
 void exec_expr(int interpreter, char *expr)
 {
-	void (*execfn)();
+	void (*execfn)(char *);
 
 	if (interpreter < 0 || interpreter >= interpreter_count) return;
 	execfn = interpreters[interpreter].execfn;
@@ -109,7 +108,7 @@ void va_execute(char *fmt, ...)
 
 /* ---
 */
-void init_interpreters()
+void init_interpreters(void)
 {
 	interpreter_count = 0;
 }
