@@ -1,6 +1,6 @@
 /*
    plot.c
-   Copyright (C) 1999-2001  Ulric Eriksson <ulric@siag.nu>
+   Copyright (C) 1999-2003  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -571,9 +571,9 @@ int main(int argc, char **argv)
 	common_init(NULL);
 	sprintf(tmpfile, "%s/siagimage.xpm", siag_tmpdir);
 
-	topLevel = XtAppInitialize(&ac, "Image",
+	topLevel = XtOpenApplication(&ac, "Image",
 		NULL, 0, &argc, argv,
-		NULL, NULL, 0);
+		NULL, mwApplicationShellWidgetClass, NULL, 0);
 
 	if (!topLevel) {
 		exit(1);
