@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ replaced by segments.
 #include <unistd.h>
 
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 #include "../common/plugin.h"
 
 #include "pw.h"
@@ -77,28 +77,29 @@ returns the name of a component in a structured file. Caller must free
 static char *file_name(buffer *buf, char *n)
 {
         char b[1024];
-        plugin_basedir(buf, b);
+        plugin_basedir(b, buf->name);
         strcat(b, "/");
         strcat(b, n);
-        return cstrdup(b);
+        return MwStrdup(b);
 }
 
 /* ---
 Returns: 0 if successful, otherwise 1
 */
 
-static rich_char empty_line[] = {{0, 0}};
+static MwRichchar empty_line[] = {{0, 0}};
 
 static int save_flat(char *fn, buffer * buf)
 {
 	int i, lr;
 	int s;
 	FILE *fp;
-	int sh = style_height(STY_DEFAULT);
-	int sf = style_table[STY_DEFAULT].format;
-	char *used_fmt = ccalloc(nformat+1, 1);
-	char *used_style = ccalloc(nstyle+1, 1);
-	int fmt, oldfmt;
+	int sh = style_height(MW_STY_DEFAULT);
+	int sf = style_table[MW_STY_DEFAULT].format;
+	char *used_fmt = MwCalloc(MwFormatCount+1, 1);
+	char *used_style = MwCalloc(nstyle+1, 1);
+	int f, oldfmt;
+	MwFmt fmt;
 
 	if ((fp = fopen(fn, "w")) == (FILE *) 0)
 		return 1;
@@ -119,21 +120,21 @@ static int save_flat(char *fn, buffer * buf)
 	fprintf(fp, ".footer %s\n", buf->footer);
 	fprintf(fp, ".header_on_first %d\n", buf->header_on_first);
 	fprintf(fp, ".first_page %d\n", buf->first_page_number);
-	fprintf(fp, ".tab_distance %d\n", buf->tab_distance);
 
 	for (s = 0; s < buf->nsht; s++) {
 		fprintf(fp, ".sheet %d %s\n", s, buf->sht[s].name);
 		lr = line_last_used(buf, s);
 		fprintf(fp, "# %s\n# %d lines\n#\n", fn, lr);
+		fprintf(fp, ".tabs %s\n", buf->sht[s].tabs);
 	
 		for (i = 1; i <= lr; i++) {
 			int height = cell_height(buf, s, i);
 			if (height != sh)
 				fprintf(fp, ".rh %d %d\n", i, height);
-			if (buf->sht[s].text[i].sty != STY_DEFAULT)
+			if (buf->sht[s].text[i].sty != MW_STY_DEFAULT)
 				fprintf(fp, ".st %d %d\n",
 					i, buf->sht[s].text[i].sty);
-			if (buf->sht[s].text[i].adj != HADJ_LEFT)
+			if (buf->sht[s].text[i].adj != MW_HADJ_LEFT)
 				fprintf(fp, ".ad %d %d\n",
 					i, buf->sht[s].text[i].adj);
 		}
@@ -152,29 +153,30 @@ static int save_flat(char *fn, buffer * buf)
 
 		for (i = 1; i <= lr; i++) {
 			int j = 0, col = 1;
-			rich_char *line = buf->sht[s].text[i].p;
+			MwRichchar *line = buf->sht[s].text[i].p;
 			if (ret_bop(buf, s, i))
 				fprintf(fp, ".bop\n");
-			if (rc_strlen(line) == 0) line = empty_line;
+			if (MwRcStrlen(line) == 0) line = empty_line;
 			fprintf(fp, "# Line %d", i);
 	
 			oldfmt = -1;
 			while (line[j].c) {
-				fmt = line[j].fmt;
-				if (fmt != oldfmt) {
+				f = line[j].fmt;
+				if (f != oldfmt) {
+					MwDecodeFormat(f, ~0, &fmt);
 					putc('\n', fp);
-					if (!used_style[format_table[fmt].style]) {
-						save_styles(fp, format_table[fmt].style);
-						used_style[format_table[fmt].style] = 1;
+					if (!used_style[fmt.style]) {
+						save_styles(fp, fmt.style);
+						used_style[fmt.style] = 1;
 					}
-					if (!used_fmt[fmt]) {
-						save_formats(fp, fmt);
-						used_fmt[fmt] = 1;
+					if (!used_fmt[f]) {
+						MwSaveFormats(fp, f);
+						used_fmt[f] = 1;
 					}
 					fprintf(fp, "%d %d %d\t\"",
-						i, col++, fmt);
+						i, col++, f);
 				}
-				oldfmt = fmt;
+				oldfmt = f;
 				putc(line[j++].c, fp);
 			}
 			putc('\n', fp);
@@ -182,8 +184,8 @@ static int save_flat(char *fn, buffer * buf)
 	}
 	fprintf(fp, "# End of file %s\n", fn);
 	fclose(fp);
-	cfree(used_fmt);
-	cfree(used_style);
+	MwFree(used_fmt);
+	MwFree(used_style);
 	return 0;
 }				/* save_flat */
 
@@ -197,7 +199,7 @@ static int load_flat(char *fn, buffer * buf)
 	long f;
 	FILE *fp;
 	char instring[256], *p, *contents;
-	int sf = style_table[STY_DEFAULT].format;
+	int sf = style_table[MW_STY_DEFAULT].format;
 	int *fmts = NULL;
 	int nfmt = -1;
 	int *styles = NULL;
@@ -214,12 +216,12 @@ static int load_flat(char *fn, buffer * buf)
 
 	while (fgets(instring, 250, fp) != NULL) {
 		char b[1024];
+		b[0] = '\0';
 		switch (instring[0]) {
 		case '\0':
 		case '#':
 			break;
 		case '.':
-			b[0] = '\0';
 			if (!strncmp(instring, ".margins ", 9)) {
 				sscanf(instring, ".margins %d %d %d %d %d %d",
 				       &(buf->top_margin),
@@ -234,22 +236,22 @@ static int load_flat(char *fn, buffer * buf)
 				       &(buf->paper_width),
 				       &(buf->paper_height),
 				       &(buf->orientation));
-			   	buf->paper_name = cstrdup(b);
+			   	buf->paper_name = MwStrdup(b);
 			} else if (!strncmp(instring, ".header ", 8)) {
 			   	sscanf(instring, ".header %[^\n]", b);
-				buf->header = cstrdup(b);
+				buf->header = MwStrdup(b);
 			} else if (!strncmp(instring, ".footer ", 8)) {
 				sscanf(instring, ".footer %[^\n]", b);
-				buf->footer = cstrdup(b);
+				buf->footer = MwStrdup(b);
 			} else if (!strncmp(instring, ".header_on_first ", 17)) {
 				sscanf(instring, ".header_on_first %d",
 				       &(buf->header_on_first));
 			} else if (!strncmp(instring, ".first_page ", 12)) {
 				sscanf(instring, ".first_page %d",
 				       &(buf->first_page_number));
-			} else if (!strncmp(instring, ".tab_distance ", 14)) {
-				sscanf(instring, ".tab_distance %d",
-				       &(buf->tab_distance));
+			} else if (!strncmp(instring, ".tabs ", 6)) {
+				sscanf(instring, ".tabs %[^\n]", b);
+				buf->sht[s].tabs = MwStrdup(b);
 			} else if (!strcmp(instring, ".bop\n")) {
 				willbop = 1;
 				forcebop = 0;
@@ -262,21 +264,21 @@ static int load_flat(char *fn, buffer * buf)
 				buf->sht[s].text[i].height = h;
 			} else if (!strncmp(instring, ".ft ", 4)) {
 				int n;
-				sfmt fmt;
+				MwFmt fmt;
 				sscanf(instring, ".ft%d", &n);
 				if (n > nfmt) {
 					nfmt = n;
-					fmts = crealloc(fmts,
+					fmts = MwRealloc(fmts,
 							(nfmt+1)*sizeof *fmts);
 				}
-				fmts[n] = load_formats(fp);
+				fmts[n] = MwLoadFormats(fp);
 				/* now replace style with the real one */
-				decode_format(fmts[n], ~0, &fmt);
+				MwDecodeFormat(fmts[n], ~0, &fmt);
 				/* look out for bogus styles */
 				if (fmt.style < nsty
 					&& styles[fmt.style] < nstyle) {
 					fmt.style = styles[fmt.style];
-					fmts[n] = encode_format(~0, &fmt);
+					fmts[n] = MwEncodeFormat(~0, &fmt);
 				} else {
 					fmt.style = 0;
 				}
@@ -285,7 +287,7 @@ static int load_flat(char *fn, buffer * buf)
 				sscanf(instring, ".style %d", &n);
 				if (n >= nsty) {
 					nsty = n;
-					styles = crealloc(styles,
+					styles = MwRealloc(styles,
 							(nsty+1)*sizeof *styles);
 				}
 				styles[n] = load_styles(fp);
@@ -309,7 +311,7 @@ static int load_flat(char *fn, buffer * buf)
 				int h;
 				char b[256];
 				sscanf(instring, ".sty%d %[^\n]", &h, b);
-				h >>= FMT_SHIFT;
+				h >>= MW_FMT_SHIFT;
 			} else if (!strncmp(instring, ".plugin-geometry ", 17)) {
 				int n, width, height;
 				n = sscanf(instring, ".plugin-geometry %d %d",
@@ -327,14 +329,14 @@ static int load_flat(char *fn, buffer * buf)
 					&row, &col, name);
 				plugin.row = row;
 				plugin.col = col;
-				plugin.name = cstrdup(name);
+				plugin.name = MwStrdup(name);
 				p = file_name(buf, name);
 				lastph = plugin.ph = plugin_start(p);
-				cfree(p);
+				MwFree(p);
 				plugin.displayed = 0;
 				if (plugin.ph != -1) {
 					n = buf->sht[s].nplugin++;
-					buf->sht[s].plugin = crealloc(buf->sht[s].plugin,
+					buf->sht[s].plugin = MwRealloc(buf->sht[s].plugin,
                                                 buf->sht[s].nplugin*sizeof(plugin_t));
                                         buf->sht[s].plugin[n] = plugin;
 				}
@@ -352,7 +354,7 @@ static int load_flat(char *fn, buffer * buf)
 			}
 			f = strtol(p, &p, 10);
 			if (nfmt == -1 || f > nfmt) {	/* old */
-				f = fmt_old2new(f);
+				f = MwFmtOldToNew(f);
 			} else {
 				f = fmts[f];
 			}
@@ -437,18 +439,18 @@ static int save(char *fn, buffer *buf)
 	        for (i = 0; i < buf->sht[s].nplugin; i++) {
 	                b = file_name(buf, buf->sht[s].plugin[i].name);
 	                plugin_save(buf->sht[s].plugin[i].ph, b);
-	                cfree(b);
+	                MwFree(b);
 	        }
 	}
         /* save the main file */
         b = file_name(buf, "INDEX.pw");
         result = save_flat(b, buf);
-        cfree(b);
+        MwFree(b);
 
         /* tar up the lot */
         sprintf(cmd, "(cd %s;tar cf - *)>%s", dir, fn);
         system(cmd);
-        cfree(dir);
+        MwFree(dir);
         return result;
 }
 
@@ -464,14 +466,14 @@ So first try flat, then tar, then flat again.
 
 static int load(char *fn, buffer *buf)
 {
-        char cmd[1024];
+        char b[1024], cmd[1024];
         char *p;
         int n;
 
         if (flatfile(fn) || !tryuntar(fn, "INDEX.pw"))
                 return load_flat(fn, buf);
 
-        p = plugin_basedir(buf, NULL);
+        p = plugin_basedir(b, buf->name);
         sprintf(cmd,
 		"mkdir -p %s;"
 		"cat %s|(cd %s;tar xf -)",
@@ -479,7 +481,7 @@ static int load(char *fn, buffer *buf)
         system(cmd);
         p = file_name(buf, "INDEX.pw");
         n = load_flat(p, buf);
-        cfree(p);
+        MwFree(p);
         return n;
 }
  
@@ -498,7 +500,7 @@ static int myformat(char *fn)
 
         ext = strrchr(fn, '.');
         if (!ext) return 0;     /* no extension */
-        if (cstrcasecmp(ext, ".pw"))
+        if (MwStrcasecmp(ext, ".pw"))
                 return 0;       /* wrong extension */
 	if (flatfile(fn))
 		return 1;	/* old format */
@@ -517,7 +519,7 @@ static int myformat(char *fn)
 /* ---
 */
 
-void fileio_pw_init()
+void fileio_pw_init(void)
 {
 	register_format(load, save, myformat, "Pathetic Writer (*.pw)");
 }
