@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-1999  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 
 #include "pw.h"
 #include "../common/common.h"
-#include "../common/cmalloc.h"
+#include <Mowitz/MwUtils.h>
 
 typedef struct s_rtf_font {
 	int nr;
@@ -66,7 +66,7 @@ static int rtf_fontnr(char *name)
 	int i;
 
 	for (i = 0; i < RTF_NROFFONTS; i++) {
-		if (!cstrcasecmp(name, fnt[i].name))
+		if (!MwStrcasecmp(name, fnt[i].name))
 			return fnt[i].nr;
 	}
 	return fnt[0].nr;
@@ -106,36 +106,36 @@ static void styledef(FILE *fpo, rtf_style s)
 
 static int rtf_fontno(int fmt)
 {
-	sfmt ft;
-	decode_format(fmt, ~0, &ft);
+	MwFmt ft;
+	MwDecodeFormat(fmt, ~0, &ft);
 	return rtf_fontnr(ft.family);
 }
 
 static int rtf_fontsize(int fmt)
 {
-	sfmt ft;
-	decode_format(fmt, ~0, &ft);
+	MwFmt ft;
+	MwDecodeFormat(fmt, ~0, &ft);
 	return ft.size*2/10;
 }
 
 static int rtf_isbold(int fmt)
 {
-	sfmt ft;
-	decode_format(fmt, ~0, &ft);
+	MwFmt ft;
+	MwDecodeFormat(fmt, ~0, &ft);
 	return ft.bold;
 }
 
 static int rtf_isitalic(int fmt)
 {
-	sfmt ft;
-	decode_format(fmt, ~0, &ft);
+	MwFmt ft;
+	MwDecodeFormat(fmt, ~0, &ft);
 	return ft.italic;
 }
 
 static int rtf_isulined(int fmt)
 {
-	sfmt ft;
-	decode_format(fmt, ~0, &ft);
+	MwFmt ft;
+	MwDecodeFormat(fmt, ~0, &ft);
 	return ft.uline;
 }
 
@@ -151,9 +151,9 @@ static rtf_style *rtf_makestyle(rtf_style *s, int i)
 	s->bold = rtf_isbold(fmt);
 	s->font = rtf_fontno(fmt);
 	s->size = rtf_fontsize(fmt);
-	s->basedon = STY_DEFAULT;
+	s->basedon = MW_STY_DEFAULT;
 	s->next = style_table[i].follower;
-	s->brk = (i == STY_PREFORMAT ? 1 : 0);
+	s->brk = (i == MW_STY_PREFORMAT ? 1 : 0);
 	strcpy(s->name, style_table[i].name);
 	return s;
 }
@@ -163,7 +163,7 @@ static void rtf_styles(FILE *fpo)
 	int i;
 
 	fprintf(fpo, "{\\stylesheet\n");
-	for (i = STY_DEFAULT; i < STY_EMBED; i++) {
+	for (i = MW_STY_DEFAULT; i < MW_STY_EMBED; i++) {
 		rtf_style s;
 		rtf_makestyle(&s, i);
 		styledef(fpo, s);
@@ -176,12 +176,12 @@ static rtf_style getstyle(int nr)
 	int i;
 	static rtf_style s;
 
-	for (i = STY_DEFAULT; i < STY_EMBED; i++) {
+	for (i = MW_STY_DEFAULT; i < MW_STY_EMBED; i++) {
 		rtf_makestyle(&s, i);
 		if (s.nr == nr) return s;
 	}
 
-	rtf_makestyle(&s, STY_DEFAULT);
+	rtf_makestyle(&s, MW_STY_DEFAULT);
 	return s;
 }
 
@@ -285,7 +285,7 @@ start new paragraph for each of these cases (heuristic alert):
 Changed by Ulric 990522: New paragraph if bop.
 */
 
-static int save_line(FILE *fp, int sty, int bop, rich_char *p)
+static int save_line(FILE *fp, int sty, int bop, MwRichchar *p)
 {
 	int i;
 	if (bop) {
@@ -295,7 +295,7 @@ static int save_line(FILE *fp, int sty, int bop, rich_char *p)
 	}
 	/* This isn't really enough. We also need to handle adjustment,
 	   line height and such. Get back to this... */
-	for (i = 0; i < rc_strlen(p); i++) {
+	for (i = 0; i < MwRcStrlen(p); i++) {
 		if (save_char(fp, /*format_table[*/p[i].fmt/*]*/, p[i].c))
 			return 1;
 	}
@@ -388,6 +388,7 @@ typedef struct doc_prop {
     char fFacingp;              /* facing pages enabled? */
     char fLandscape;            /* landscape or portrait?? */
     int fDefFont;		/* default font number */
+    char fMac;			/* hack to deal with mac charset */
 } DOP;                  /* DOcument Properties */
 
 typedef enum { rdsNorm, rdsSkip, rdsFonttbl } RDS;  /* Rtf Destination State */
@@ -412,6 +413,7 @@ typedef enum {ipropBold, ipropItalic, ipropUnderline,
               ipropPgnY, ipropXaPage, ipropYaPage, ipropXaLeft,
               ipropXaRight, ipropYaTop, ipropYaBottom, ipropPgnStart,
               ipropSbk, ipropPgnFormat, ipropFacingp, ipropLandscape,
+	      ipropMac,
               ipropJust, ipropPard, ipropPlain, ipropSectd,
               ipropMax } IPROP;
 
@@ -510,6 +512,7 @@ PROP rgprop [ipropMax] = {
     {actnByte,   propSep,    offsetof(SEP, pgnFormat)},   /* ipropPgnFormat */
     {actnByte,   propDop,    offsetof(DOP, fFacingp)},    /* ipropFacingp */
     {actnByte,   propDop,    offsetof(DOP, fLandscape)},  /* ipropLandscape */
+    {actnByte,	 propDop,    offsetof(DOP, fMac)},	  /* ipropMac */
     {actnByte,   propPap,    offsetof(PAP, just)},        /* ipropJust */
     {actnSpec,   propPap,    0},                          /* ipropPard */
     {actnSpec,   propChp,    0},                          /* ipropPlain */
@@ -520,7 +523,7 @@ PROP rgprop [ipropMax] = {
 SYM rgsymRtf[] = {
 /*  keyword     dflt    fPassDflt   kwd         idx */
     {"b",        1,      fFalse,     kwdProp,    ipropBold},
-    {"u",        1,      fFalse,     kwdProp,    ipropUnderline},
+    {"ul",       1,      fFalse,     kwdProp,    ipropUnderline},
     {"i",        1,      fFalse,     kwdProp,    ipropItalic},
     {"fs",	 24,	 fFalse,     kwdProp,	 ipropFontSize},
     {"f",	 0,	 fFalse,     kwdProp,	 ipropFontNo},
@@ -554,6 +557,7 @@ SYM rgsymRtf[] = {
     {"pgnstart", 1,      fTrue,      kwdProp,    ipropPgnStart},
     {"facingp",  1,      fTrue,      kwdProp,    ipropFacingp},
     {"landscape",1,      fTrue,      kwdProp,    ipropLandscape},
+    {"mac",	 1,	 fFalse,     kwdProp,	 ipropMac},
     {"par",      0,      fFalse,     kwdChar,    '\n'},
     {"\n",       0,      fFalse,     kwdChar,    '\n'},
     {"\r",       0,      fFalse,     kwdChar,    '\n'},
@@ -825,6 +829,7 @@ static int load(char *fn, buffer *b)
         return 1;
     }
     row = 1;
+    b->height_interest = 0;	/* fix heights later */
     set_bop(b, 0, row, 1);
     buf = b;
     if ((ec = ecRtfParse(fp)) != ecOK)
@@ -834,6 +839,7 @@ static int load(char *fn, buffer *b)
         printf("Parsed RTF file OK\n");
 #endif
     fclose(fp);
+    b->height_interest = 1;
     for (row = 1; row <= line_last_used(b, 0); row++)
 		rebreak_line(b, 0, row);
     b->change = 0;
@@ -1070,7 +1076,7 @@ static int ecFontName(int ch)
 	char b[2];
 
 	if (ch == ';') {	/* no more to come */
-		fonttbl[chp.fNo].name = cstrdup(fontname);
+		fonttbl[chp.fNo].name = MwStrdup(fontname);
 		fontname[0] = '\0';
 	} else {		/* add to the font name */
 		b[0] = ch;
@@ -1111,26 +1117,46 @@ static int ecParseChar(int ch)
 
 /* ---
 Send a character to the output file.
+
+001225: hack to deal with mac charset
 */
 
 static int ecPrintChar(int ch)
 {
-	sfmt fmt;
+	MwFmt fmt;
 	int s = 0;
 
+	if (dop.fMac) {
+		switch (ch) {
+		case 0x88: ch = ''; break;
+		case 0x89: ch = ''; break;
+		case 0x8d: ch = ''; break;
+		case 0x8e: ch = ''; break;
+		case 0x8f: ch = ''; break;
+		case 0x90: ch = ''; break;
+		case 0x94: ch = ''; break;
+		case 0x95: ch = ''; break;
+		case 0x99: ch = ''; break;
+		case 0x9d: ch = ''; break;
+		case 0x9e: ch = ''; break;
+		case 0xcf: ecPrintChar('o'); ch = 'e'; break;	/* FIXME */
+		default: break;
+		}
+	}
+
 	if (ch == '\n') {
 		row++;
 		set_bop(buf, s, row, 1);
 	} else {
-		decode_format(0, ~0, &fmt);
-		fmt.family = lookup_fontalias(fonttbl[chp.fNo].name);
+		MwDecodeFormat(0, ~0, &fmt);
+		fmt.family = MwLookupFontAlias(fonttbl[chp.fNo].name);
 		if (fmt.family == NULL) fmt.family = "Helvetica";
 		fmt.bold = chp.fBold;
 		fmt.italic = chp.fItalic;
 		fmt.uline = chp.fUnderline;
 		fmt.size = 5*chp.fSize;	/* twips => decipoints */
 		ins_char(buf, s, row, line_length(buf, s, row), ch,
-			encode_format(~0, &fmt));
+			MwEncodeFormat(~0, &fmt));
 	}
 
     return ecOK;
@@ -1151,7 +1177,7 @@ static int myformat(char *fn)
 
         ext = strrchr(fn, '.');
         if (!ext) return 0;     /* no extension */
-        if (cstrcasecmp(ext, ".rtf"))
+        if (MwStrcasecmp(ext, ".rtf"))
                 return 0;       /* wrong extension */
         if ((fp = fopen(fn, "r")) == NULL) return 0;    /* can't open */
         while (fgets(b, sizeof b, fp)) {
@@ -1166,7 +1192,7 @@ static int myformat(char *fn)
 
 /* ---
 */
-void fileio_rtf_init()
+void fileio_rtf_init(void)
 {
 	register_format(load, save, myformat, "Rich Text Format (*.rtf)");
 }
