@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997, 1998  Ulric Eriksson <ulric@edu.stockholm.se>
+   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,8 @@
    MA 02111-1307, USA.
  */
 
-#ifdef TCL
+#include "../config.h"
+#ifdef HAVE_LIBTCL
 
 /*
  * tcli.c
