@@ -4,7 +4,7 @@
 
 (add_menu "File")
 
-(add_menu_entry "File" "New" "(new_buffer)")
+(add_menu_entry "File" "New ^N" "(new_buffer)")
 (add_menu_entry "File" "Open" "(load_buffer)")
 (add_menu_entry "File" "Save" "(save_buffer)")
 (add_menu_entry "File" "Save As" "(save_buffer_as)")
@@ -39,6 +39,11 @@
 
 (add_menu "Edit")
 (add_menu_entry "Edit" "Undo" "(undo_restore)")
+(add_menu_entry "Edit" "-" "-")
+(add_menu_entry "Edit" "Cut" "(cut_to_clipboard)")
+(add_menu_entry "Edit" "Copy" "(copy_to_clipboard)")
+(add_menu_entry "Edit" "Paste" "(paste_from_clipboard)")
+(add_menu_entry "Edit" "-" "-")
 (add_menu_entry "Edit" "Delete" "(delete_cell)")
 (add_menu_entry "Edit" "Insert Line" "(insert_line)")
 (add_menu_entry "Edit" "Remove Line" "(remove_line)")
@@ -46,10 +51,6 @@
 (add_menu_entry "Edit" "Remove Column" "(remove_col)")
 (add_menu_entry "Edit" "Select All" "(select_all)")
 (add_menu_entry "Edit" "-" "-")
-(add_menu_entry "Edit" "Cut" "(cut_block_to_string)")
-(add_menu_entry "Edit" "Copy" "(copy_block_to_string)")
-(add_menu_entry "Edit" "Paste" "(paste_block_from_string)")
-(add_menu_entry "Edit" "-" "-")
 (add_menu_entry "Edit" "Find" "(search_forward)")
 (add_menu_entry "Edit" "Find Backward" "(search_backward)")
 (add_menu_entry "Edit" "-" "-")
