@@ -1,6 +1,6 @@
 /*
    Egon Animator
-   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
+   Copyright (C) 1997-2003  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@
 #include "../siod/siod.h"
 #include "../egon/egon.h"
 #include "xegon.h"
-#include "drop.h"
+/*#include "drop.h"*/
 
 #include "../common/common.h"
 #include "../xcommon/embed.h"
@@ -139,6 +139,7 @@ static int stage_popped = 0;
 
 static Atom wm_delete_window;	/* Atom sent to destroy a window */
 extern Atom target_atom;	/* used for selection */
+static Atom *drop_types;
 
 static void draw_buffer(window *);
 static window *find_window_by_widget(Widget);
@@ -1322,19 +1323,69 @@ void stage_init(window *w)
 	draw_buffer(w);
 }
 
+static void cb_drag(Widget w, XtPointer client_data, XtPointer call_data)
+{                                                                        
+        DropPosition *where = (DropPosition *)call_data;
+        printf("cb_drag at (%d,%d)\n", where->x, where->y);
+}                                                          
+ 
+static void cb_drop(Widget w, XtPointer client_data, XtPointer call_data)
+{                                                                        
+        int prot = (int)call_data;
+        int dnd_type;             
+        Atom xdnd_type;
+        char *data;    
+                   
+        switch (prot) {
+        case DndDrop:  
+                printf("cb_drop received OffiX drop\n");
+                XtVaGetValues(w,                        
+                        XtNdndType, &dnd_type,
+                        XtNdropData, &data,   
+                        (char *)0);
+                printf("type = %d, data = '%s'\n", dnd_type, data);
+                break;
+        case XdndDrop:
+                printf("cb_drop received Xdnd drop\n");
+                XtVaGetValues(w,
+                        XtNxdndType, &xdnd_type,
+                        XtNdropData, &data,
+                        (char *)0);
+                printf("type = '%s', data = '%s'\n",
+                        XGetAtomName(XtDisplay(w), xdnd_type), data);
+                break;
+        case MotifDrop:
+                printf("cb_drop received Motif drop\n");
+                break;
+        default:
+                printf("cb_drop received unknown drop\n");
+                break;
+        }
+}
+
 static void init_windows1(int *argc, char **argv)
 {
 	XtSetLanguageProc(NULL, (XtLanguageProc) NULL, NULL);
 
-	topLevel = XtVaAppInitialize(
+	topLevel = XtVaOpenApplication(
 		    &app_context,	/* application context */
 		    "Egon",		/* application class */
 		    options,		/* command line options list */
 		    XtNumber(options),
 		    argc, argv,	/* command line args */
 		    fallback_resources,	/* for missing app-defaults file */
+		    mwApplicationShellWidgetClass,
 		    NULL);		/* terminate varargs list */
 
+	drop_types[0] = XInternAtom(XtDisplay(topLevel), "text/plain", False);
+	drop_types[1] = XInternAtom(XtDisplay(topLevel), "text/uri-list", False);
+	drop_types[2] = None;
+	XtVaSetValues(topLevel,
+		XtNdropTypes, drop_types,
+		(char *)0);
+	XtAddCallback(topLevel, XtNdragCallback, cb_drag, NULL);
+	XtAddCallback(topLevel, XtNdropCallback, cb_drop, NULL);
+
 	theme_init(XtDisplay(topLevel));
 
 	XSetErrorHandler(MwXErrorHandler);
@@ -1449,7 +1500,6 @@ void init_windows(buffer * b, int *argc, char **argv)
 	init_form(topLevel);
 
 	MwSetIcon(topLevel, egon_xpm);
-	drop_init(topLevel);
 
 	stop_splash();
 }
