@@ -32,20 +32,16 @@
 #include <X11/Xaw/Viewport.h>
 #include <X11/Xaw/Toggle.h>
 #include <X11/Xaw/Label.h>
+#include <Mowitz/Mowitz.h>
 
 #include <X11/xpm.h>
 
-#include "../common/common.h"
-#include "../common/cmalloc.h"
-#include "../xcommon/Frame.h"
-#include "../xcommon/Handle.h"
-#include "../xcommon/Tooltip.h"
-#include "../xcommon/Rudegrid.h"
-#include "../xcommon/TextField.h"
-#include "../xcommon/xcommon.h"
-
 #include "Files.h"
 
+#include "../common/common.h"
+#include <Mowitz/Mowitz.h>
+#include "../xcommon/xcommon.h"
+
 #define FW_WIDTH 400
 #define FW_HEIGHT 300
 #define TEXT_PADDING 10
@@ -155,7 +151,8 @@ static MenuItemRec view_menu[] = {
 static MenuItemRec help_menu[] = {
 	{ "contents", "Contents", helpContentsCb },
 	{ "line1", NULL, NULL },
-	{ "about", "About", helpAboutCb },
+	{ "aboutxfiler", "About Xfiler...", helpAboutXfilerCb },
+	{ "aboutsiag", "About Siag Office...", helpAboutSiagCb },
 };
 
 /*-----------------------------------------------------------------------------
@@ -283,29 +280,33 @@ static Arg line_args[] = {
 -----------------------------------------------------------------------------*/
 
 static char label_translations_s[] = "\
-  <Btn1Up>(2)         : fileRefresh()\n";
+  :<Btn1Up>(2)         : fileRefresh()\n";
 
 static char tree_translations_s[] = "\
-  <Btn1Down>,<Btn1Up> : fileSelect()\n\
+  Shift<Btn1Down>,<Btn1Up>: fileToggle()\n\
+  :<Btn1Down>,<Btn1Up> : fileSelect()\n\
   <Btn2Down>,<Btn2Up> : fileToggle()\n\
   <Btn3Down>          : dirPopup()\n";
 
 
 static char dir_translations_s[] = "\
-  <Btn1Up>(2)         : fileOpenDir()\n\
-  <Btn1Down>,<Btn1Up> : fileSelect()\n\
+  :<Btn1Up>(2)         : fileOpenDir()\n\
+  Shift<Btn1Down>,<Btn1Up>: fileToggle()\n\
+  :<Btn1Down>,<Btn1Up> : fileSelect()\n\
   <Btn2Down>,<Btn2Up> : fileToggle()\n\
   <Btn3Down>          : dirPopup()\n";
 
 static char file_translations_s[] = "\
-  <Btn1Up>(2)         : fileExecAction()\n\
-  <Btn1Down>,<Btn1Up> : fileSelect()\n\
+  :<Btn1Up>(2)         : fileExecAction()\n\
+  Shift<Btn1Down>,<Btn1Up>: fileToggle()\n\
+  :<Btn1Down>,<Btn1Up> : fileSelect()\n\
   <Btn2Down>,<Btn2Up> : fileToggle()\n\
   <Btn3Down>          : filePopup()\n";
 
 static char exec_translations_s[] = "\
-  <Btn1Up>(2)         : fileExecFile()\n\
-  <Btn1Down>,<Btn1Up> : fileSelect()\n\
+  :<Btn1Up>(2)         : fileExecFile()\n\
+  Shift<Btn1Down>,<Btn1Up>: fileToggle()\n\
+  :<Btn1Down>,<Btn1Up> : fileSelect()\n\
   <Btn2Down>,<Btn2Up> : fileToggle()\n\
   <Btn3Down>          : filePopup()\n";
 
@@ -333,7 +334,7 @@ static void cmd_shift(void)
 {
 	int i;
 
-	cfree(cmd_history[0]);
+	MwFree(cmd_history[0]);
 	for (i = 1; i < cmd_count; i++)
 		cmd_history[i-1] = cmd_history[i];
 	cmd_history[i-1] = NULL;
@@ -343,7 +344,7 @@ static void cmd_shift(void)
 static void cmd_store(char *p)
 {
 	if (cmd_count >= CMD_MAX) cmd_shift();
-	cmd_history[cmd_count++] = cstrdup(p);
+	cmd_history[cmd_count++] = MwStrdup(p);
 }
 
 static char *cmd_get(int n)
@@ -355,9 +356,64 @@ static char *cmd_get(int n)
 	return cmd_history[n];
 }
 
+static FileWindowRec *find_window_by_widget(Widget w)
+{
+	FileWindowRec *fw;
+	for (fw = file_windows; fw; fw = fw->next) {
+		if (w == fw->shell || w == fw->form
+		    || w == fw->viewport || w == fw->status
+		    || w == fw->icon_box || w == fw->menubar
+		    || w == fw->menubox || w == fw->toolbar
+		    || w == fw->toolbox || w == fw->cmdform
+		    || w == fw->cmdframe || w == fw->cmdtext
+		    || w == fw->menuhandle || w == fw->toolhandle) {
+			return fw;
+		}
+	}
+	return NULL;
+}
+
 static void cmdline_run(Widget w, XEvent *e, String *p, Cardinal *n)
 {
-	String string = TextFieldGetString(w);
+	String string = MwTextFieldGetString(w);
+
+	/* This is a hack of the worst kind, allowing the user to invoke the
+	   default action of a file just by pressing Enter when the command
+	   line is empty.
+	*/
+	if (string[0] == '\0') {
+		int i;
+		FileWindowRec *fw = find_window_by_widget(w);
+		if (fw == NULL) {
+			return;
+		}
+		for (i = 0; i < fw->n_files; i++) {
+			if (fw->files[i]->selected)
+			break;
+		}
+		if (i < fw->n_files) {
+			int l = strlen(fw->directory);
+			char *path = MwMalloc(l+strlen(fw->files[i]->name)+2);
+			strcpy(path, fw->directory);
+			if (path[l-1] != '/') path[l++] = '/';
+			strcpy(path+l, fw->files[i]->name);
+
+			if (S_ISDIR(fw->files[i]->stats.st_mode)) {
+				fileOpenDir(fw->files[i]->icon.toggle,
+					NULL, NULL, NULL);
+			} else if (S_ISREG(fw->files[i]->stats.st_mode)) {
+				if (fw->files[i]->stats.st_mode &
+				    (S_IXUSR | S_IXGRP | S_IXOTH)) {
+					fileExecFile(fw->files[i]->icon.toggle,
+						NULL, NULL, NULL);
+				} else {
+					fileExecAction(fw->files[i]->icon.toggle,
+						NULL, NULL, NULL);
+				}
+			}
+		}
+		return;
+	}
 
 	cmd_store(string);
 	cmd_curr = cmd_count;
@@ -366,32 +422,104 @@ static void cmdline_run(Widget w, XEvent *e, String *p, Cardinal *n)
 		argv[0] = "runcmd";
 		argv[1] = "/bin/sh";
 		argv[2] = "-c";
-		argv[3] = cstrdup(string);
+		argv[3] = MwStrdup(string);
 		argv[4] = NULL;
 		execvp(argv[0], argv);
 		_exit(0);	/* shouldn't get here */
 	}
 	string = "";
-	TextFieldSetString(w, string);
+	MwTextFieldSetString(w, string);
 }
 
 static void cmdline_cancel(Widget w, XEvent *e, String *p, Cardinal *n)
 {
 	String string = "";
-	TextFieldSetString(w, string);
+	MwTextFieldSetString(w, string);
 	cmd_curr = cmd_count;
 }
 
 static void cmdline_previous(Widget w, XEvent *e, String *p, Cardinal *n)
 {
 	String string = cmd_get(cmd_curr-1);
-	TextFieldSetString(w, string);
+	MwTextFieldSetString(w, string);
 }
 
 static void cmdline_next(Widget w, XEvent *e, String *p, Cardinal *n)
 {
 	String string = cmd_get(cmd_curr+1);
-	TextFieldSetString(w, string);
+	MwTextFieldSetString(w, string);
+}
+
+static void cmdline_tab(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+	int i;
+	FileWindowRec *fw = find_window_by_widget(w);
+	if (fw == NULL) {
+		return;
+	}
+	for (i = 0; i < fw->n_files; i++) {
+		if (fw->files[i]->selected)
+		break;
+	}
+	if (i < fw->n_files) {
+		if (p[0][0] == 'l' && i > 0) {				/* left */
+			fileToggle(fw->files[i]->icon.toggle, NULL, NULL, 0);
+			fileSelect(fw->files[i-1]->icon.toggle, NULL, NULL, 0);
+		} else if (p[0][0] == 'r' && i < (fw->n_files-1)) {	/* right */
+			fileToggle(fw->files[i]->icon.toggle, NULL, NULL, 0);
+			fileSelect(fw->files[i+1]->icon.toggle, NULL, NULL, 0);
+		}
+	} else if (p[0][0] == 'l') {
+		fileSelect(fw->files[fw->n_files-1]->icon.toggle, NULL, NULL, 0);
+	} else if (p[0][0] == 'r') {
+		fileSelect(fw->files[0]->icon.toggle, NULL, NULL, 0);
+	}
+}
+
+static void cmdline_copy(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+#if 0
+	FileWindowRec *fw = find_window_by_widget(w);
+#endif
+}
+
+static void cmdline_cut(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+#if 0
+	FileWindowRec *fw = find_window_by_widget(w);
+#endif
+}
+
+static void cmdline_paste(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+#if 0
+	FileWindowRec *fw = find_window_by_widget(w);
+#endif
+}
+
+static void cmdline_quit(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+	FileWindowRec *fw = find_window_by_widget(w);
+	toplevelCloseCb(w, fw, NULL);
+}
+
+static void cmdline_close(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+	FileWindowRec *fw = find_window_by_widget(w);
+	fileCloseCb(w, fw, NULL);
+}
+
+static void cmdline_update(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+	FileWindowRec *fw = find_window_by_widget(w);
+	updateIconsCb(w, fw, NULL);
+}
+
+static void cmdline_new(Widget w, XEvent *e, String *p, Cardinal *n)
+{
+	FileWindowRec *fw = find_window_by_widget(w);
+	newFileWindow(fw->directory, resources.default_display_type,
+		False, False);
 }
 
 static XtActionsRec file_actions[] = {
@@ -404,11 +532,18 @@ static XtActionsRec file_actions[] = {
   { "filePopup", filePopup },
   { "dirPopup", dirPopup },
   { "dummy", dummy },
-  { "menu-motion", dummy },
   { "cmdline-run", cmdline_run },
   { "cmdline-cancel", cmdline_cancel },
   { "cmdline-previous", cmdline_previous },
   { "cmdline-next", cmdline_next },
+  { "cmdline-tab", cmdline_tab },
+  { "cmdline-update", cmdline_update },
+  { "cmdline-copy", cmdline_copy },
+  { "cmdline-cut", cmdline_cut },
+  { "cmdline-paste", cmdline_paste },
+  { "cmdline-close", cmdline_close },
+  { "cmdline-quit", cmdline_quit },
+  { "cmdline-new", cmdline_new },
 };
 
 static XtTranslations label_translations, dir_translations, file_translations, 
@@ -749,9 +884,9 @@ void forget_icons(Display *dpy)
 	while (pm_cache) {
 		pl = pm_cache;
 		pm_cache = pl->next;
-		cfree(pl->name);
+		MwFree(pl->name);
 		XFreePixmap(dpy, pl->pm);
-		cfree(pl);
+		MwFree(pl);
 	}
 }
 
@@ -761,20 +896,23 @@ static Pixmap load_custom_icon(Widget w, char *name)
 	char b[1024], c[1024];
 	struct stat statbuf;
 	pm_list *pl;
+	Pixel color;
 
 	getcwd(b, 1000);
-	sprintf(c, "%s/.xfiler/%s.xpm", b, name);
+	/* new method, place files in ~/.siag/.xfiler/`pwd`/filename.xpm */
+	sprintf(c, "%s/.xfiler%s/%s.xpm", siag_basedir, b, name);
 	for (pl = pm_cache; pl; pl = pl->next) {
 		if (pl->name && !strcmp(pl->name, c)) {
 			return pl->pm;
 		}
 	}
 	if (stat(c, &statbuf)) return None;
-	pm = load_pixmap(w, c);
+	XtVaGetValues(w, XtNbackground, &color, (char *)0);
+	pm = load_pixmap(XtDisplay(w), color, c);
 	if (pm) {
 		pl = (pm_list *)malloc(sizeof(pm_list));
 		pl->pm = pm;
-		pl->name = cstrdup(c);
+		pl->name = MwStrdup(c);
 		pl->next = pm_cache;
 		pm_cache = pl;
 	}
@@ -806,7 +944,7 @@ static void createFileIcons(FileWindowRec *fw)
   fw->icon_box = XtCreateWidget("icon box",  boxWidgetClass,
     fw->viewport, icon_box_args, XtNumber(icon_box_args) );
 	/* register icon_box as a "droppable" */
-	DndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
+	MwDndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
 
   for (i=0; i < fw->n_files; i++) {
     Pixel back;
@@ -837,22 +975,26 @@ static void createFileIcons(FileWindowRec *fw)
     }
     else if (S_ISDIR(file->stats.st_mode)) {
       icon_toggle_args[3].value = (XtArgVal) dir_translations;
-      if (icon == None)
-	if (file->sym_link)
+      if (icon == None) {
+	if (file->sym_link) {
 	  icon = (XtArgVal) bm[DIRLNK_BM];
-	else if (!strcmp(file->name, ".."))
+	} else if (!strcmp(file->name, "..")) {
 	  icon = (XtArgVal) bm[UPDIR_BM];
-        else
+        } else {
 	  icon = (XtArgVal) bm[DIR_BM];
+	}
+      }
       icontype = 0;
     }
     else if (file->stats.st_mode & (S_IXUSR | S_IXGRP | S_IXOTH)) {
       icon_toggle_args[3].value = (XtArgVal) exec_translations;
-      if (icon == None)
-	if (file->sym_link)
+      if (icon == None) {
+	if (file->sym_link) {
 	  icon = (XtArgVal) bm[EXECLNK_BM];
-	else
+	} else {
 	  icon = (XtArgVal) bm[EXEC_BM];
+	}
+      }
       icontype = 2;
     }
     else {
@@ -866,14 +1008,16 @@ static void createFileIcons(FileWindowRec *fw)
       /* This is our opportunity to load a custom icon /Ulric */
       icon = load_custom_icon(file->icon.form, file->name);
 
-      if (icon == None)
-        if (file->type)
+      if (icon == None) {
+        if (file->type) {
 	  icon = (XtArgVal) file->type->icon_bm;
-	else if (file->sym_link)
+	} else if (file->sym_link) {
 	  icon = (XtArgVal) bm[SYMLNK_BM];
-	else
+	} else {
 	  icon = (XtArgVal) bm[FILE_BM];
+	}
       icontype = 1;
+      }
     }
     icon_toggle_args[2].value = icon;
 
@@ -881,8 +1025,8 @@ static void createFileIcons(FileWindowRec *fw)
       toggleWidgetClass, file->icon.form, icon_toggle_args,
       XtNumber(icon_toggle_args) );
     /* Register Widget for Dnd */
-    DndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
-    DndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
+    MwDndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
+    MwDndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
 	  
     XtVaGetValues(file->icon.toggle, XtNbackground, &back, NULL);
     XtVaSetValues(file->icon.toggle, XtNborder, (XtArgVal) back, NULL);
@@ -940,7 +1084,7 @@ static void createTextDisplay(FileWindowRec *fw)
 				fw->viewport, icon_box_args,
 				XtNumber(icon_box_args) );
   /* register icon_box as a "droppable" */
-  DndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
+  MwDndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
 
   for (i=0; i<fw->n_files; i++) {
     Pixel pix;
@@ -978,8 +1122,8 @@ static void createTextDisplay(FileWindowRec *fw)
       toggleWidgetClass, file->icon.form, text_toggle_args,
       XtNumber(text_toggle_args) );
 
-	DndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
-	DndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
+	MwDndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
+	MwDndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
 
     XtVaGetValues(file->icon.toggle, file->selected?XtNforeground:
 		  XtNbackground, &pix, NULL);
@@ -1069,8 +1213,8 @@ static Widget createDirIcon(FileWindowRec *fw, int i, Widget horiz,Widget vert)
     toggleWidgetClass, file->icon.form, icon_toggle_args,
     XtNumber(icon_toggle_args) );
 
- DndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
- DndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
+ MwDndRegisterDragWidget(file->icon.toggle, DragEventHandler, NULL);
+ MwDndRegisterDropWidget(file->icon.toggle, DropEventHandler, NULL);
 
   XtVaGetValues(file->icon.toggle, XtNbackground, &back, NULL);
   XtVaSetValues(file->icon.toggle, XtNborder, (XtArgVal) back, NULL);
@@ -1124,7 +1268,7 @@ static void createTreeDisplay(FileWindowRec *fw)
     fw->viewport, tree_box_args, XtNumber(tree_box_args) );
 
 	/* register icon_box as a "droppable" */
-	 DndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
+	 MwDndRegisterDropWidget(fw->icon_box, IconBoxDropEventHandler, NULL);
 
   /* The '..' directory is not displayed, and no arrow for '.'  */
   files[1]->icon.form = files[1]->icon.toggle = 
@@ -1315,7 +1459,7 @@ static Widget make_command(FmCallbackProc cb,
                 commandWidgetClass, pw,
                 XtNforeground, color,
                 (char *)NULL);
-	pm_return = load_pixmap(pw, pm);
+	pm_return = load_pixmap(XtDisplay(pw), color, pm);
 
         XtVaSetValues(w,
                 XtNbitmap, pm_return,
@@ -1323,7 +1467,7 @@ static Widget make_command(FmCallbackProc cb,
 
         XtAddCallback(w,
                 XtNcallback, (XtCallbackProc)cb, (XtPointer)data);
-	TooltipAdd(tooltip, w, translate(tt));
+	MwTooltipAdd(tooltip, w, _(tt));
         return w;
 }
 
@@ -1353,23 +1497,6 @@ static void create_toolbar(Widget pw, XtPointer fw)
 		     "Display the online documentation");
 }
 
-static FileWindowRec *find_window_by_widget(Widget w)
-{
-	FileWindowRec *fw;
-	for (fw = file_windows; fw; fw = fw->next) {
-		if (w == fw->shell || w == fw->form
-		    || w == fw->viewport || w == fw->status
-		    || w == fw->icon_box || w == fw->menubar
-		    || w == fw->menubox || w == fw->toolbar
-		    || w == fw->toolbox || w == fw->cmdform
-		    || w == fw->cmdframe || w == fw->cmdtext
-		    || w == fw->menuhandle || w == fw->toolhandle) {
-			return fw;
-		}
-	}
-	return NULL;
-}
-
 static void remake_ylayout(FileWindowRec *fw)
 {
 	char b[100];
@@ -1381,7 +1508,7 @@ static void remake_ylayout(FileWindowRec *fw)
 		(char *)0);
 }
 
-static void attach_bar(Widget w)
+static void attach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
 	FileWindowRec *fw = find_window_by_widget(w);
 	if (fw == NULL) return;
@@ -1390,7 +1517,7 @@ static void attach_bar(Widget w)
 	remake_ylayout(fw);
 }
 
-static void detach_bar(Widget w)
+static void detach_bar(Widget w, XtPointer client_data, XtPointer call_data)
 {
 	FileWindowRec *fw = find_window_by_widget(w);
 	if (fw == NULL) return;
@@ -1399,24 +1526,6 @@ static void detach_bar(Widget w)
 	remake_ylayout(fw);
 }
 
-static Widget make_handle(Widget pw, Widget victim)
-{
-	Pixmap pm;
-	Pixel color;
-	XtVaGetValues(pw,
-		      XtNbackground, &color,
-		      (char *)0);
-	pm = load_pixmap(pw, "handlebg.xpm");
-	return XtVaCreateManagedWidget("handle",
-		handleWidgetClass, pw,
-		XtNforeground, color,
-		XtNbackgroundPixmap, pm,
-		XtNshadowWidth, 1,
-		XtNhandleDetach, detach_bar,
-		XtNhandleAttach, attach_bar,
-		XtNhandleVictim, victim,
-		(char *)0);
-}
 
 /*---------------------------------------------------------------------------*/
 /* Create a file Window at the specified path, in the specified format */
@@ -1441,7 +1550,7 @@ static FileWindowRec *createFileWindow(String path, String title,
   fw->next = file_windows;
   file_windows = fw;
   
-  if (!getwd(fw->directory)) {
+  if (!getcwd(fw->directory, MAXPATHLEN)) {
     sysError("Can't open folder:");
     return NULL;
   }
@@ -1476,32 +1585,43 @@ static FileWindowRec *createFileWindow(String path, String title,
   
   /* create form */
   fw->form = XtVaCreateManagedWidget("topbox",
-		rudegridWidgetClass, fw->shell,
+		mwRudegridWidgetClass, fw->shell,
 		(char *)0);
   fw->menubar = XtVaCreateManagedWidget("menubar",
-		frameWidgetClass, fw->form,
+		mwRudegridWidgetClass, fw->form,
+		XtNborderWidth, 0,
+		XtNxLayout, "9 100%",
 		(char *)0);
+  MwMakeHandle(fw->menubar, fw->menubar, detach_bar, attach_bar);
   fw->menubox = XtVaCreateManagedWidget("menubox",
-		boxWidgetClass, fw->menubar,
+		mwMenuBarWidgetClass, fw->menubar,
+		XtNgridx, 1,
 		(char *)0);
   fw->bars |= MENUBAR;
-  fw->menuhandle = make_handle(fw->menubox, fw->menubar);
   fw->toolbar = XtVaCreateManagedWidget("toolbar",
-		frameWidgetClass, fw->form,
+		mwRudegridWidgetClass, fw->form,
+		XtNborderWidth, 0,
+		XtNxLayout, "9 100%",
+		(char *)0);
+  fw->toolhandle = MwMakeHandle(fw->toolbar, fw->toolbar,
+			detach_bar, attach_bar);
+  fw->toolbox = XtVaCreateManagedWidget("frame2",
+		mwFrameWidgetClass, fw->toolbar,
+		XtNgridx, 1,
+		XtNshadowWidth, 1,
 		(char *)0);
   fw->toolbox = XtVaCreateManagedWidget("toolbox",
-		boxWidgetClass, fw->toolbar,
+		boxWidgetClass, fw->toolbox,
 		(char *)0);
   fw->bars |= TOOLBAR;
-  fw->toolhandle = make_handle(fw->toolbox, fw->toolbar);
   fw->cmdform = XtVaCreateManagedWidget("cmdform",
 		formWidgetClass, fw->form,
 		(char *)0);
   fw->cmdframe = XtVaCreateManagedWidget("cmdframe",
-		frameWidgetClass, fw->cmdform,
+		mwFrameWidgetClass, fw->cmdform,
 		(char *)0);
   fw->cmdtext = XtVaCreateManagedWidget("cmdtext",
-		textfieldWidgetClass, fw->cmdframe,
+		mwTextfieldWidgetClass, fw->cmdframe,
 		(char *)0);
 
   XtSetKeyboardFocus(fw->form, fw->cmdtext);
@@ -1540,7 +1660,7 @@ static FileWindowRec *createFileWindow(String path, String title,
 #endif
 
   /* Drag and drop stuff */
-  DndAddShell(fw->shell);
+  MwDndAddShell(fw->shell);
 
   return fw;
 }
@@ -1607,7 +1727,7 @@ void createFileDisplay(FileWindowRec *fw)
   if (!readDirectory(fw)) {
     fw->unreadable = 
       XtVaCreateManagedWidget("label", labelWidgetClass, fw->viewport,
-			      XtNlabel, translate("Directory is unreadable"),
+			      XtNlabel, _("Directory is unreadable"),
 			      NULL);
     return;
   }
@@ -1856,6 +1976,7 @@ void updateStatus(FileWindowRec *fw)
   noTick(fw->view_items[4]);
   noTick(fw->view_items[5]);
   noTick(fw->view_items[6]);
+  noTick(fw->view_items[8]);
 
   switch (fw->display_type) {
   case Tree:
