@@ -22,12 +22,11 @@
 #include <X11/Shell.h>
 #include <X11/Xaw/Toggle.h>
 
+#include "Files.h"
+
 #include "../common/common.h"	/* for ABORT */
 
-#include "../xcommon/dialogs.h"
-#include "../xcommon/TextField.h"
-
-#include "Files.h"
+#include <Mowitz/Mowitz.h>
 
 /*---------------------------------------------------------------------------
   STATIC DATA
@@ -288,13 +287,13 @@ from the menu (Folder - New) or from the toolbar. The popup
 has two callbacks, mkdirOkCb and mkdirCancelCb, which are used
 by the dialog's two buttons.
 
-Instead of this, we will call dialog_input_icon() in xcommon.
+Instead of this, we will call MwDialogInputIcon() in xcommon.
 There is no need for the two button-specific callbacks and we
 do not need to create the dialog in advance. By implementing
 this for all callbacks, it will be possible to remove a large
 amount of code, which is also poorly written and hard to maintain.
 
-dialog_input_icon has these advantages:
+MwDialogInputIcon has these advantages:
  - handles keyboard focus
  - handles translation for i18n
 */
@@ -308,7 +307,7 @@ void mkdirPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 		fnexpand(b);
@@ -337,7 +336,7 @@ void createFilePopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 		fnexpand(b);
@@ -368,7 +367,7 @@ void openWithPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
 	if (fw == NULL) fw = popup_fw;
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 		fnexpand(b);
@@ -396,7 +395,7 @@ void goToPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	popups.fw = fw;
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 	   fnexpand(b);
@@ -404,7 +403,7 @@ void goToPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	      char s[0xff];
 	      sprintf(s, "Can't open folder %s:", b);
 	      sysError(s);
-	   } else if (!getwd(b))
+	   } else if (!getcwd(b, MAXPATHLEN))
 		sysError("System error:");
 	   else {
 	      strcpy(popups.fw->directory, b);
@@ -431,7 +430,7 @@ void movePopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	popups.fw = fw;
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 	   struct stat stats;
@@ -452,7 +451,7 @@ void movePopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 
 	      if (!stat(to, &stats) && S_ISDIR(stats.st_mode)) {
 
-		 if (chdir(to) || !getwd(to) || chdir(popups.fw->directory)) {
+		 if (chdir(to) || !getcwd(to, MAXPATHLEN) || chdir(popups.fw->directory)) {
 		    sysError("System error:");
 		    goto out;
 		 } else if (!strcmp(popups.fw->directory, to)) {
@@ -480,11 +479,10 @@ void movePopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		      if (exists(to) && resources.confirm_overwrite) {
 			 char s[0xff];
 			 sprintf(s, "Move: file %s already exists at destination", from);
-			 if (!confirm(s, "Overwrite?", ""))
-			   if (aborted)
-			     break;
-			 else
-			   continue;
+			 if (!confirm(s, "Overwrite?", "")) {
+			   if (aborted) break;
+			 else continue;
+			 }
 		      }
 		      if (rename(from,to)) {
 			 char s[0xff];
@@ -536,7 +534,7 @@ void movePopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		 } else {
 		    n_moved = 1;
 		    dir_prefix(todir, to);
-		    if ((*todir?chdir(todir):0) || !getwd(todir))
+		    if ((*todir?chdir(todir):0) || !getcwd(todir, MAXPATHLEN))
 		      sysError("System error:");
 		 }
 	      }
@@ -570,7 +568,7 @@ void copyPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	popups.fw = fw;
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 	   struct stat stats;
@@ -591,7 +589,7 @@ void copyPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 
 	      if (!stat(to, &stats) && S_ISDIR(stats.st_mode)) {
 
-		 if (chdir(to) || !getwd(to) || chdir(popups.fw->directory)) {
+		 if (chdir(to) || !getcwd(to, MAXPATHLEN) || chdir(popups.fw->directory)) {
 		    sysError("System error:");
 		    goto out;
 		 } else if (!strcmp(popups.fw->directory, to)) {
@@ -619,11 +617,10 @@ void copyPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		      if (exists(to) && resources.confirm_overwrite) {
 			 char s[0xff];
 			 sprintf(s, "Copy: file %s already exists at destination", from);
-			 if (!confirm(s, "Overwrite?", ""))
-			   if (aborted)
-			     break;
-			 else
-			   continue;
+			 if (!confirm(s, "Overwrite?", "")) {
+			   if (aborted) break;
+			 else continue;
+			 }
 		      }
 		      if (rcopy(from,to)) {
 			 char s[0xff];
@@ -675,7 +672,7 @@ void copyPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		 } else {
 		    n_copied = 1;
 		    dir_prefix(todir, to);
-		    if ((*todir?chdir(todir):0) || !getwd(todir))
+		    if ((*todir?chdir(todir):0) || !getcwd(todir, MAXPATHLEN))
 		      sysError("System error:");
 		 }
 	      }
@@ -710,7 +707,7 @@ void linkPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 	popups.fw = fw;
 	freeze = True;	/* what's that for? */
 	b[0] = '\0';
-	n = dialog_input_icon(fw->shell, t, p, b, icon);
+	n = MwDialogInputIcon(fw->shell, t, p, b, icon);
 
 	if (n != ABORT) {
 	   struct stat stats;
@@ -739,7 +736,7 @@ void linkPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 
 	      if (!stat(to, &stats) && S_ISDIR(stats.st_mode)) {
 
-		 if (chdir(to) || !getwd(to) || chdir(popups.fw->directory)) {
+		 if (chdir(to) || !getcwd(to, MAXPATHLEN) || chdir(popups.fw->directory)) {
 		    sysError("System error:");
 		    goto out;
 		 } else if (!strcmp(popups.fw->directory, to)) {
@@ -763,11 +760,10 @@ void linkPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		      if (exists(to) && resources.confirm_overwrite) {
 			 char s[0xff];
 			 sprintf(s, "Link: file %s already exists at destination", from);
-			 if (!confirm(s, "Overwrite?", ""))
-			   if (aborted)
-			     break;
-			 else
-			   continue;
+			 if (!confirm(s, "Overwrite?", "")) {
+			   if (aborted) break;
+			 else continue;
+			 }
 		      }
 		      if (symlink(name,to)) {
 			 char s[0xff];
@@ -818,7 +814,7 @@ void linkPopup(Widget w, FileWindowRec *fw, XtPointer call_data)
 		 } else {
 		    n_linked = 1;
 		    dir_prefix(todir, to);
-		    if ((*todir?chdir(todir):0) || !getwd(todir))
+		    if ((*todir?chdir(todir):0) || !getcwd(todir, MAXPATHLEN))
 		      sysError("System error:");
 		 }
 	      }
