@@ -36,15 +36,6 @@
 	<Key>Escape:			cmdline-cancel()\\n\
 	<Key>Up:			cmdline-previous()\\n\
 	Ctrl<Key>p:			cmdline-previous()\\n\
-	~Shift<Key>Tab:			cmdline-tab(right)\\n\
-	Shift<Key>Tab:			cmdline-tab(left)\\n\
-	Ctrl<Key>c:			cmdline-copy()\\n\
-	Ctrl<Key>x:			cmdline-cut()\\n\
-	Ctrl<Key>v:			cmdline-paste()\\n\
-	Ctrl<Key>q:			cmdline-quit()\\n\
-	Ctrl<Key>w:			cmdline-close()\\n\
-	Ctrl<Key>u:			cmdline-update()\\n\
-	Ctrl<Key>n:			cmdline-new()\\n\
 	<Key>Down:			cmdline-next()\\n\
 	Ctrl<Key>n:			cmdline-next()",
 "Xfiler*Box.handle.height:		28",
@@ -75,9 +66,9 @@
 "Xfiler*viewport.icon box*Command.shadowWidth: 	0",
 "Xfiler*viewport.icon box*Label.justify:		Center",
 "Xfiler*chmod.form.Form.Command.highlightThickness:0",
-"Xfiler*boldFont:			-*-helvetica-bold-r-*-*-14-*",
-"Xfiler*iconFont:			-*-helvetica-medium-r-*-*-12-*",
-"Xfiler*labelFont:		-*-helvetica-medium-r-*-*-12-*",
+"Xfiler*boldFont:			-*-helvetica-bold-r-*-*-14-*-*-*-*-*-iso8859-*",
+"Xfiler*iconFont:			-*-helvetica-medium-r-*-*-12-*-*-*-*-*-iso8859-*",
+"Xfiler*labelFont:		-*-helvetica-medium-r-*-*-12-*-*-*-*-*-iso8859-*",
 "Xfiler*cellFont:		fixed",
 "Xfiler*appIconWidth: 72",
 "Xfiler*appIconHeight: 60",
