@@ -1,6 +1,6 @@
 /*
    Pathetic Writer
-   Copyright (C) 1997-2002  Ulric Eriksson <ulric@siag.nu>
+   Copyright (C) 1997-2003  Ulric Eriksson <ulric@siag.nu>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
 
@@ -61,7 +62,7 @@
 
 #include "../pw/pw.h"
 #include "xpw.h"
-#include "drop.h"
+/*#include "drop.h"*/
 
 #include "../siod/siod.h"
 
@@ -98,6 +99,10 @@ float zoom = 1.0;
 
 static int bars = 0;
 
+static int we_have_selection, start_row, start_col;
+static int we_have_clipboard;
+static char *clip_string;
+
 typedef struct {
         Boolean plugin;
 } AppData;
@@ -136,7 +141,303 @@ static Cursor grid_cursor;
 static unsigned long blockbg, noblockbg;
 
 Atom wm_delete_window;	/* Atom sent to destroy a window */
-extern Atom target_atom;	/* used for selection */
+Atom target_atom;	/* used for selection */
+Atom clipboard;
+Atom *drop_types;
+
+/* Selection stuff */
+
+/* ---
+   Module name:    selection.c
+
+   This module handles selection: grabbing, releasing, cutting, pasting.
+
+   The selection uses a custom target PW_BLOCK, which is simple
+   plaintext. No formatting is preserved.
+
+   All in all, plenty good enough for now.
+--- */
+
+Boolean convert_proc(Widget w,
+	Atom *selection, Atom *target, Atom *type_return,
+	XtPointer *value_return, unsigned long *length_return,
+	int *format_return)
+{
+	window *wl = find_window_by_widget(w);
+	unsigned int lr;
+
+	XSelectionRequestEvent *req = XtGetSelectionRequest(w,
+		*selection, (XtRequestId) NULL);
+
+	/* handle all required atoms, and the one that we use */
+	/* Xt already handles MULTIPLE, no branch necessary */
+	if (*target == XA_TARGETS(XtDisplay(w))) {
+		Atom *targetP;
+		Atom *std_targets;
+		unsigned long std_length;
+		XmuConvertStandardSelection(w, req->time, selection,
+			target, type_return,
+			(XPointer *)&std_targets,
+			&std_length, format_return);
+		*value_return = XtMalloc(sizeof(Atom)*(std_length+1));
+		targetP = *(Atom **)value_return;
+		*length_return = std_length+1;
+		*targetP++ = target_atom;
+		memcpy(targetP, std_targets, sizeof(Atom)*std_length);
+		XtFree((char *)std_targets);
+		*type_return = XA_ATOM;
+		*format_return = sizeof(Atom)*8;
+		return True;
+	} else if (*target == target_atom) {
+		/* handle normal selection */
+		char *data = pack_area(wl->buf, wl->bsht,
+			block_upper(wl).row, block_upper(wl).col,
+			block_lower(wl).row, block_lower(wl).col,
+			&lr);
+		*length_return = lr;
+		*value_return = XtMalloc(*length_return);
+		memcpy(*value_return, data, *length_return);
+		MwFree(data);
+		*type_return = target_atom;
+
+		*format_return = 8;
+		return True;
+	} else if (*target == XA_STRING) {
+		/* handle string selections (from outside PW) */
+		char *data = pack_area(wl->buf, wl->bsht,
+			block_upper(wl).row, block_upper(wl).col,
+			block_lower(wl).row, block_lower(wl).col,
+			&lr);
+		*length_return = strlen(data);
+		*value_return = XtMalloc(*length_return+1);
+		memcpy(*value_return, data, *length_return+1);
+		MwFree(data);
+
+		*type_return = XA_STRING;
+		*format_return = 8;
+		return True;
+	} else {
+		if (XmuConvertStandardSelection(w, CurrentTime, selection,
+				target, type_return, (XPointer *)value_return,
+				length_return, format_return))
+			return True;
+		else {
+#if 0	/* so what? */
+			char *p = XGetAtomName(XtDisplay(w), *target);
+			XtWarning("PW: unsupported selection type");
+			XtWarning(p);
+			XFree(p);
+#endif
+			return False;
+		}
+	}
+}
+
+Boolean convert_clip_proc(Widget w,
+	Atom *selection, Atom *target, Atom *type_return,
+	XtPointer *value_return, unsigned long *length_return,
+	int *format_return)
+{
+	XSelectionRequestEvent *req = XtGetSelectionRequest(w,
+		*selection, (XtRequestId) NULL);
+
+	/* handle all required atoms, and the one that we use */
+	/* Xt already handles MULTIPLE, no branch necessary */
+	if (*target == XA_TARGETS(XtDisplay(w))) {
+		Atom *targetP;
+		Atom *std_targets;
+		unsigned long std_length;
+		XmuConvertStandardSelection(w, req->time, selection,
+			target, type_return,
+			(XPointer *)&std_targets,
+			&std_length, format_return);
+		*value_return = XtMalloc(sizeof(Atom)*(std_length+1));
+		targetP = *(Atom **)value_return;
+		*length_return = std_length+1;
+		*targetP++ = target_atom;
+		memcpy(targetP, std_targets, sizeof(Atom)*std_length);
+		XtFree((char *)std_targets);
+		*type_return = XA_ATOM;
+		*format_return = sizeof(Atom)*8;
+		return True;
+	} else if (*target == target_atom) {
+		/* handle normal selection */
+		char *data = clip_string;
+		*length_return = strlen(data);
+		*value_return = XtMalloc(*length_return+1);
+		strcpy(*value_return, data);
+		*type_return = target_atom;
+
+		*format_return = 8;
+		return True;
+	} else if (*target == XA_STRING) {
+		/* handle string selections (from outside PW) */
+		char *data = clip_string;
+		*length_return = strlen(data);
+		*value_return = XtMalloc(*length_return+1);
+		strcpy(*value_return, data);
+
+		*type_return = XA_STRING;
+		*format_return = 8;
+		return True;
+	} else {
+		if (XmuConvertStandardSelection(w, CurrentTime, selection,
+				target, type_return, (XPointer *)value_return,
+				length_return, format_return))
+			return True;
+		else {
+#if 0	/* so what? */
+			char *p = XGetAtomName(XtDisplay(w), *target);
+			XtWarning("PW: unsupported selection type");
+			XtWarning(p);
+			XFree(p);
+#endif
+			return False;
+		}
+	}
+}
+
+void lose_ownership_proc(Widget w, Atom *selection)
+{
+	window *wl = find_window_by_widget(w);
+	int s = wl->bsht;
+	sheet *st = wl->buf->sht;
+	wl->bsht = -1;
+
+	st[s].blku.row = st[s].blku.col = -1;
+	st[s].blkl.row = st[s].blkl.col = -1;
+
+	pr_scr_flag = TRUE;	/* Is this enough? */	
+	show_cur(wl);
+}
+
+void drop_clipboard(void)
+{
+	if (!we_have_clipboard) return;
+	we_have_clipboard = 0;
+	XtDisownSelection(w_list->ui->grid, clipboard, CurrentTime);
+	MwFree(clip_string);
+	clip_string = NULL;
+}
+
+void lose_clip_proc(Widget w, Atom *selection)
+{
+	drop_clipboard();
+}
+
+void transfer_done_proc(Widget w, Atom *a, Atom *b)
+{
+	; /* no need to do anything at all */
+}
+
+void string_requestor_callback(Widget w, XtPointer client_data,
+        Atom *selection, Atom *type, XtPointer value,
+        unsigned long *length, int *format)
+{
+        if ((value == NULL) && (*length == 0)) {
+                XBell(XtDisplay(w), 100);
+                XtWarning("PW: no selection or selection timed out");
+        } else {
+                unpack_string_area(w_list->buf, (char *)value,
+			w_list->sht,
+                        get_point(w_list).row, get_point(w_list).col);
+                w_list->buf->change = TRUE;
+                XtFree((char *)value);
+                pr_scr_flag = TRUE;
+        }
+	show_cur(w_list);
+}
+
+void requestor_callback(Widget w, XtPointer client_data,
+	Atom *selection, Atom *type, XtPointer value,
+	unsigned long *length, int *format)
+{
+	if ((value == NULL) && (*length == 0)) {
+        /* if we asked for a PW_BLOCK and got a null response,
+           we'll ask again, this time for an XA_STRING */
+                XtGetSelectionValue(w, *selection, XA_STRING,
+                        string_requestor_callback,
+                        NULL, CurrentTime);     /* NULL is bogus event */
+	} else {
+		unpack_area(w_list->buf, (char *)value,
+			w_list->sht,
+			get_point(w_list).row, get_point(w_list).col);
+		w_list->buf->change = TRUE;
+
+		XtFree((char *)value);
+		pr_scr_flag = TRUE;
+	}
+	show_cur(w_list);
+}
+
+static void drop_selection(void)
+{
+	if (!we_have_selection) return;
+	we_have_selection = 0;
+	XtDisownSelection(w_list->ui->grid, XA_PRIMARY, CurrentTime);
+	w_list->bsht = -1;
+	pr_scr_flag = TRUE;
+	show_cur(w_list);
+}
+
+static void start_selection(void)
+{
+	if (we_have_selection) return;
+	if (XtOwnSelection(w_list->ui->grid, XA_PRIMARY, CurrentTime,
+			convert_proc, lose_ownership_proc, NULL) == False) {
+		XtWarning("PW failed to become selection owner");
+		return;
+	}
+	we_have_selection = 1;
+	start_row = get_point(w_list).row;
+	start_col = get_point(w_list).col;
+}
+
+static void start_clipboard(void)
+{
+	position p1, p2;
+	p1 = block_upper(w_list);
+	p2 = block_lower(w_list);
+	drop_clipboard();
+	if (XtOwnSelection(w_list->ui->grid, clipboard, CurrentTime,
+			convert_clip_proc, lose_clip_proc, NULL) == False) {
+		XtWarning("PW failed to become clipboard owner");
+		return;
+	}
+	clip_string = pack_string(w_list->buf, w_list->sht,
+			p1.row, p1.col, p2.row, p2.col);
+	we_have_clipboard = 1;
+}
+
+static void set_selection(void)
+{
+	int s = w_list->sht;
+	sheet *st = w_list->buf->sht;
+	int r1, c1, r2, c2;
+	position p = get_point(w_list);
+	if (start_row < p.row || (start_row == p.row && start_col < p.col)) {
+		r1 = start_row;
+		c1 = start_col;
+		r2 = p.row;
+		c2 = p.col;
+	} else {
+		r1 = p.row;
+		c1 = p.col;
+		r2 = start_row;
+		c2 = start_col;
+	}
+	if (c2) c2--;	/* at least this is less wrong */
+
+	w_list->bsht = w_list->sht;
+	st[s].blku.row = r1;
+	st[s].blku.col = c1;
+	st[s].blkl.row = r2;
+	st[s].blkl.col = c2;
+	pr_scr_flag = TRUE;
+	show_cur(w_list);
+}
+
+/* End of selection stuff */
 
 /* ---
 */
@@ -536,7 +837,7 @@ static void set_block(int row1, int col1, int row2, int col2)
         if (XtOwnSelection(w_list->ui->grid, XA_PRIMARY,
 		CurrentTime, convert_proc,
                 lose_ownership_proc, transfer_done_proc) == False) {
-                XtWarning("PW: failed to become selection owner\n");
+                XtWarning("PW: failed to become selection owner");
                 st[s].blku.row = st[s].blku.col = -1;
                 st[s].blkl.row = st[s].blkl.col = -1;
         }
@@ -625,6 +926,107 @@ void GridButtonAction(Widget w, XEvent *event, String *params, Cardinal *n)
         show_cur(w_list);
 }
 
+static void extend_left(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	start_selection();
+	execute("(backward-char)");
+	set_selection();
+}
+
+static void extend_right(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	start_selection();
+	execute("(forward-char)");
+	set_selection();
+}
+
+static void extend_up(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	start_selection();
+	execute("(previous-line)");
+	set_selection();
+}
+
+static void extend_down(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	start_selection();
+	execute("(next-line)");
+	set_selection();
+}
+
+static void backward_char(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	drop_selection();
+	execute("(backward-char)");
+}
+
+static void forward_char(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	drop_selection();
+	execute("(forward-char)");
+}
+
+static void next_line(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	drop_selection();
+	execute("(next-line)");
+}
+
+static void previous_line(Widget w, XEvent *event, String *params, Cardinal *n)
+{
+	drop_selection();
+	execute("(previous-line)");
+}
+
+static void cut_to_clipboard(Widget w, XEvent *event,
+			String *params, Cardinal *n)
+{
+	if (!we_have_selection) {
+		return;
+	}
+	start_clipboard();
+	execute("(delete-block)");
+	pr_scr_flag = TRUE;
+	show_cur(w_list);
+}
+
+static void copy_to_clipboard(Widget w, XEvent *event,
+			String *params, Cardinal *n)
+{
+	if (!we_have_selection) {
+		return;
+	}
+	start_clipboard();
+}
+
+static void paste_from_clipboard(Widget w, XEvent *event,
+			String *params, Cardinal *n)
+{
+	XtGetSelectionValue(w, clipboard, target_atom,
+			requestor_callback, event, CurrentTime);
+	pr_scr_flag = TRUE;
+	show_cur(w_list);
+}
+
+static LISP lcut_to_clipboard(void)
+{
+	cut_to_clipboard(w_list->ui->grid, NULL, NULL, NULL);
+	return NIL;
+}
+
+static LISP lcopy_to_clipboard(void)
+{
+	copy_to_clipboard(w_list->ui->grid, NULL, NULL, NULL);
+	return NIL;
+}
+
+static LISP lpaste_from_clipboard(void)
+{
+	paste_from_clipboard(w_list->ui->grid, NULL, NULL, NULL);
+	return NIL;
+}
+
+
 /*
 This action is extremely messy, being copied from the application code
 of Pathetic Writer. We need to do it like this instead:
@@ -649,9 +1051,9 @@ static void SelfInsertChar(Widget w, XEvent *event, String *params, Cardinal *n)
 	unsigned char buf[12];
 	KeySym keysym;
 
-	unselect_block(w_list);
 	hide_cur(w_list);
 	count = MwRichtextLookupString(w, event, buf, bufsiz, &keysym);
+	if (count) unselect_block(w_list);
 	if (keysym >= ' ' && count == 1) {
 		int s = w_list->sht;
 		sheet *st = w_list->buf->sht;
@@ -1240,11 +1642,11 @@ static void init_toolbar(void)
         make_command("(print)", toolbox, "printer.xpm",
 		     "Print the contents of the current buffer");
 	make_vsep(toolbox);
-	make_command("(cut-block-to-string)", toolbox, "cut.xpm",
+	make_command("(cut_to_clipboard)", toolbox, "cut.xpm",
 		     "Cut");
-	make_command("(copy-block-to-string)", toolbox, "copy.xpm",
+	make_command("(copy_to_clipboard)", toolbox, "copy.xpm",
 		     "Copy");
-	make_command("(paste-block-from-string)", toolbox, "paste.xpm",
+	make_command("(paste_from_clipboard)", toolbox, "paste.xpm",
 		     "Paste");
 	make_command("(spell-buffer)", toolbox, "spell.xpm",
 		     "Spelling checker");
@@ -1439,6 +1841,17 @@ static void popup_shortcuts(Widget w, XEvent *event,
 
 static XtActionsRec actions[] =
 {
+	{"extend_left", extend_left},
+	{"extend_right", extend_right},
+	{"extend_up", extend_up},
+	{"extend_down", extend_down},
+	{"backward_char", backward_char},
+	{"forward_char", forward_char},
+	{"previous_line", previous_line},
+	{"next_line", next_line},
+	{"cut_to_clipboard", cut_to_clipboard},
+	{"copy_to_clipboard", copy_to_clipboard},
+	{"paste_from_clipboard", paste_from_clipboard},
         {"grid-button", GridButtonAction},
 	{"self-insert-char", SelfInsertChar},
         {"siaghelp", siaghelp_action},
@@ -1446,19 +1859,70 @@ static XtActionsRec actions[] =
 	{"popup-shortcuts", popup_shortcuts},
 };
 
+static void cb_drag(Widget w, XtPointer client_data, XtPointer call_data)
+{                                                                        
+        DropPosition *where = (DropPosition *)call_data;
+        printf("cb_drag at (%d,%d)\n", where->x, where->y);
+}                                                          
+ 
+static void cb_drop(Widget w, XtPointer client_data, XtPointer call_data)
+{                                                                        
+        int prot = (int)call_data;
+        int dnd_type;             
+        Atom xdnd_type;
+        char *data;    
+                   
+        switch (prot) {
+        case DndDrop:  
+                printf("cb_drop received OffiX drop\n");
+                XtVaGetValues(w,                        
+                        XtNdndType, &dnd_type,
+                        XtNdropData, &data,   
+                        (char *)0);        
+                printf("type = %d, data = '%s'\n", dnd_type, data);
+                break;
+        case XdndDrop:
+                printf("cb_drop received Xdnd drop\n");
+                XtVaGetValues(w,
+                        XtNxdndType, &xdnd_type,
+                        XtNdropData, &data,
+                        (char *)0);
+                printf("type = '%s', data = '%s'\n",
+                        XGetAtomName(XtDisplay(w), xdnd_type), data);
+                break;
+        case MotifDrop:
+                printf("cb_drop received Motif drop\n");
+                break;
+        default:
+                printf("cb_drop received unknown drop\n");
+                break;
+        }
+}
+
 static void init_windows1(int *argc, char **argv)
 {
         XtSetLanguageProc(NULL, (XtLanguageProc) NULL, NULL);
 
-        topLevel = XtVaAppInitialize(
+        topLevel = XtVaOpenApplication(
                     &app_context,       /* application context */
                     "Pw",               /* application class */
                     options,            /* command line options list */
 		    XtNumber(options),
                     argc, argv,        /* command line args */
                     fallback_resources, /* for missing app-defaults file */
+		    mwApplicationShellWidgetClass,
                     (char *)0);         /* terminate varargs list */
 
+	drop_types = MwMalloc(3*sizeof *drop_types);
+	drop_types[0] = XInternAtom(XtDisplay(topLevel), "text/plain", False);
+	drop_types[1] = XInternAtom(XtDisplay(topLevel), "text/uri-list", False);
+	drop_types[2] = None;
+	XtVaSetValues(topLevel,
+		XtNdropTypes, drop_types,
+		(char *)0);
+	XtAddCallback(topLevel, XtNdragCallback, cb_drag, NULL);
+	XtAddCallback(topLevel, XtNdropCallback, cb_drop, NULL);
+
 	MwInitFormat(XtDisplay(topLevel));
 
 	theme_init(XtDisplay(topLevel));
@@ -1728,6 +2192,7 @@ void init_windows(buffer *b, int *argc, char **argv)
 
 	/* Set up selection */
 	target_atom = XInternAtom(display, "PW_BLOCK", False);
+	clipboard = XInternAtom(display, "CLIPBOARD", False);
 
 	/* stuff originally in realmain */
 
@@ -1738,11 +2203,13 @@ void init_windows(buffer *b, int *argc, char **argv)
         init_subr_2("add-submenu", add_submenu);
         init_subr_4("add-submenu-entry", add_submenu_entry);
         init_subr_1("tooltip-mode", ltooltip_mode);
+	init_subr_0("cut_to_clipboard", lcut_to_clipboard);
+	init_subr_0("copy_to_clipboard", lcopy_to_clipboard);
+	init_subr_0("paste_from_clipboard", lpaste_from_clipboard);
 
         init_form(topLevel, app_context);
 
         MwSetIcon(topLevel, pw_xpm);
-	drop_init(topLevel);
 
 	stop_splash();
 }
